export interface Opcion<V> {
    salto?: V | null;
}
export declare type RowData<V extends string, D> = Record<V, D>;
export declare type FuncionHabilitar<V extends string, D> = (formData: RowData<V, D>) => boolean;
export declare type FuncionValoradora<V extends string, D> = (formData: RowData<V, D>) => D | null;
export interface Variable<V extends string, D, FIN> {
    optativa?: boolean;
    salto?: V | FIN | null;
    tipo: 'opciones' | 'numerico' | 'texto' | string;
    opciones?: Record<string | number, Opcion<V | FIN>>;
    maximo?: number | null;
    minimo?: number | null;
    subordinadaVar?: V | null;
    subordinadaValor?: D | null;
    saltoNsNr?: V | FIN | null;
    calculada?: boolean | null;
    funcionHabilitar?: FuncionHabilitar<V, D> | string | null;
    libre?: boolean | null;
    funcionAutoIngresar?: FuncionValoradora<V, D> | string | null;
}
export interface Structure<V extends string, D, FIN = true> {
    variables: Record<V, Variable<V, D, FIN>>;
    marcaFin?: FIN;
}
export declare type EstadoVariableNormales = 'actual' | 'valida' | 'todavia_no' | 'calculada' | 'salteada' | 'optativa_sd';
export declare type EstadoVariableErroneas = 'invalida' | 'omitida' | 'fuera_de_rango' | 'fuera_de_flujo_por_omitida' | 'fuera_de_flujo_por_salto';
export declare type EstadoVariable = EstadoVariableNormales | EstadoVariableErroneas;
export declare type Feedback<V extends string, FIN> = {
    estado: EstadoVariable;
    siguiente: V | FIN | null | undefined;
    apagada: boolean;
    inhabilitada: boolean;
    conDato: boolean;
    conProblema: boolean;
    pendiente: boolean | null;
};
export declare type FormStructureState<V extends string, D, FIN> = {
    resumen: 'vacio' | 'con problemas' | 'incompleto' | 'ok';
    feedbackResumen: Omit<Feedback<V, FIN>, 'siguiente' | 'apagada' | 'inhabilitada'>;
    feedback: Record<V, Feedback<V, FIN>>;
    estados: Partial<Record<V, EstadoVariable>>;
    siguientes: Partial<Record<V, V | FIN | null>>;
    actual: V | null;
    primeraVacia?: V | null;
    primeraFalla: V | null;
    autoIngresadas?: Partial<RowData<V, D>>;
};
export interface RowValidatorSetup<V extends string, D> {
    getFuncionHabilitar: (name: string) => FuncionHabilitar<V, D>;
    getFuncionValorar: (name: string) => FuncionValoradora<V, D>;
    nsnrTipicos: Record<string, boolean>;
    multiEstado: boolean | null;
}
export declare type OpcionesRowValidator = {
    autoIngreso?: boolean;
};
export declare function getRowValidator<V extends string, D, FIN>(_setup: Partial<RowValidatorSetup<V, D>>): (estructura: Structure<V, D, FIN>, formData: RowData<V, D>, opts?: OpcionesRowValidator | undefined) => FormStructureState<V, D, FIN>;
//# sourceMappingURL=row-validator.d.ts.map